Given the tokens object from the `get_authentication_tokens` function and the market of interest, return specific information about that market's hours of operation. Note that a data parameter can also be specified between now and one year from now to obtain specific hours of operation for the market related to that date.
get_market_hours_single(tokens, market, date = NULL)Returns a data frame containing information surrounding the market's hours of operation.
token object from `get_authentication_tokens` function (list).
market of interest that is either "equity", "option", "bond", "future", or "forex" (string).
date you would like to get the hours of operation. Valid dates are today through one year from now. Default is NULL, which is today (date).
Nick Bultman, njbultman74@gmail.com, July 2024