Learn R Programming

charlesschwabapi (version 1.0.5)

get_option_expiration_chain: Get Option Expiration Chain

Description

Given the tokens object from the `get_authentication_tokens` function and the symbol of interest, return the option expiration chain information related to the symbol. This includes expiration dates, expiration types, settlement types, and more.

Usage

get_option_expiration_chain(tokens, symbol)

Value

Returns a data frame containing information surrounding the option expiration chain.

Arguments

tokens

token object from `get_authentication_tokens` function (list).

symbol

symbol for option expiration chain (string).

Author

Nick Bultman, njbultman74@gmail.com, June 2024