Given the tokens object from the `get_authentication_tokens` function and the symbol of interest, return the option expiration chain information related to the symbol. This includes expiration dates, expiration types, settlement types, and more.
get_option_expiration_chain(tokens, symbol)Returns a data frame containing information surrounding the option expiration chain.
token object from `get_authentication_tokens` function (list).
symbol for option expiration chain (string).
Nick Bultman, njbultman74@gmail.com, June 2024